==> pcl_1.11.1+dfsg.orig.tar.xz: pcl-pcl-1.11.1/.github/ISSUE_TEMPLATE/bug-report.md <==
---
name: Bug report
about: Create a report to help us improve PCL
title: "[module_name] Provide a general summary of the issue"
labels: 'status: triage, kind: bug'
assignees: ''

---

<!--- WARNING: This is an issue tracker. Before opening a new issue make sure you read https://github.com/PointCloudLibrary/pcl/blob/master/CONTRIBUTING.md#using-the-issue-tracker. -->
**Describe the bug**

A clear and concise description of what the bug is.

**Context**

What are you trying to accomplish? Providing context helps us come up with a solution that is most useful in the real world

**Expected behavior**

A clear and concise description of what you expected to happen.

**Current Behavior**

What happens instead of the expected behavior?

**To Reproduce**

Provide a link to a live example, or an unambiguous set of steps to reproduce this bug. A reproducible example helps to provide faster answers.

**Screenshots/Code snippets**

In order to help explain your problem, please consider adding
* screenshots of the GUI issues
* code snippets: [syntax for code](https://github.com/adam-p/markdown-here/wiki/Markdown-Cheatsheet#code) with correct language highlights

**Your Environment (please complete the following information):**

 - OS: [e.g. Ubuntu 16.04]
 - Compiler: [:eg GCC 8.1]
 - PCL Version [e.g. 1.10, HEAD]

**Possible Solution**

Not obligatory, but suggest a fix/reason for the bug. Feel free to create a PR if you feel comfortable.

**Additional context**

Add any other context about the problem here.

==> pcl_1.15.0+dfsg.orig.tar.xz: pcl-pcl-1.15.0/.github/ISSUE_TEMPLATE/bug-report.md <==
---
name: Bug report
about: Create a report to help us improve PCL
title: "[module_name] Provide a general summary of the issue"
labels: 'status: triage, kind: bug'
assignees: ''

---

<!--- WARNING: This is an issue tracker. Before opening a new issue make sure you read https://github.com/PointCloudLibrary/pcl/blob/master/CONTRIBUTING.md#using-the-issue-tracker. -->
**Describe the bug**

A clear and concise description of what the bug is.

**Context**

What are you trying to accomplish? Providing context helps us come up with a solution that is most useful in the real world

**Expected behavior**

A clear and concise description of what you expected to happen.

**Current Behavior**

What happens instead of the expected behavior?

**To Reproduce**

Provide a link to a live example, or an unambiguous set of steps to reproduce this bug. A reproducible example helps to provide faster answers. If you load data e.g. from a PCD or PLY file, please provide the file.

**Screenshots/Code snippets**

In order to help explain your problem, please consider adding
* screenshots of the GUI issues
* code snippets: [syntax for code](https://github.com/adam-p/markdown-here/wiki/Markdown-Cheatsheet#code) with correct language highlights

**Your Environment (please complete the following information):**

 - OS: [e.g. Ubuntu 16.04]
 - Compiler: [:eg GCC 8.1]
 - PCL Version [e.g. 1.10, HEAD]

**Possible Solution**

Not obligatory, but suggest a fix/reason for the bug. Feel free to create a PR if you feel comfortable.

**Additional context**

Add any other context about the problem here.
